# Generated by Django 2.2.8 on 2021-06-01 12:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('serial', '0010_devicehandler_migration'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='serialdevice',
            name='instrument',
        ),
    ]
