# Generated by Django 3.2 on 2023-02-10 10:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('serial', '0013_devicehandler_migration'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='serialdevice',
            name='instrument_handler',
        ),
    ]
