# Generated by Django 2.2.8 on 2020-09-04 08:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('serial', '0005_serialdevice_instrument'),
    ]

    operations = [
        migrations.AlterField(
            model_name='serialdevice',
            name='baudrate',
            field=models.PositiveIntegerField(default=9600, help_text='0 use default'),
        ),
        migrations.AlterField(
            model_name='serialdevice',
            name='bytesize',
            field=models.CharField(choices=[(5, 'FIVEBITS'), (6, 'SIXBITS'), (7, 'SEVENBITS'), (8, 'EIGHTBITS')], default=8, max_length=254),
        ),
        migrations.AlterField(
            model_name='serialdevice',
            name='parity',
            field=models.CharField(choices=[('N', 'NONE'), ('E', 'EVEN'), ('O', 'ODD'), ('M', 'MARK'), ('S', 'SPACE')], default='N', max_length=254),
        ),
        migrations.AlterField(
            model_name='serialdevice',
            name='port',
            field=models.CharField(default='/dev/ttyAMA0', help_text='enter serial port (/dev/pts/13))', max_length=400),
        ),
        migrations.AlterField(
            model_name='serialdevice',
            name='stopbits',
            field=models.CharField(choices=[(1, 'one stopbit'), (1.5, 'one point five stopbit'), (2, '2 stopbits')], default=1, max_length=254),
        ),
    ]
