# Generated by Django 2.2.8 on 2021-06-01 12:11

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('pyscada', '0079_devicehandler'),
        ('serial', '0008_auto_20200904_0837'),
    ]

    operations = [
        migrations.AddField(
            model_name='serialdevice',
            name='instrument_handler',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='pyscada.DeviceHandler'),
        ),
    ]
